"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Any, Union
from typing_extensions import TypeAliasType


Schema14TypedDict = TypeAliasType("Schema14TypedDict", Union[float, str, Any])


Schema14 = TypeAliasType("Schema14", Union[float, str, Any])
